==> jira-projects-plugin-4.3.2.jar: page/project/components/ItemView-test.js <==
AJS.test.require(["com.atlassian.jira.jira-projects-plugin:components-page-assets"], function(){
    "use strict";

    module('JIRA.Projects.Components.ItemView', {
        setup: function () {
            this.mockModel = new Backbone.Model();
            sinon.stub(this.mockModel, "trigger");
            this.mockModel.discard = sinon.stub();
            sinon.stub(this.mockModel, "on");
            sinon.stub(this.mockModel, "off");

            this.view = new JIRA.Projects.Components.ItemView({
                el: jQuery(
                    '<div>'+
                    '<div class="operation-retry operation-add">' +
                    '    <a class="operation-retry">Retry add</a>' +
                    '</div>'+
                    '<div class="operation-retry operation-delete">' +
                    '    <a class="operation-retry">Retry delete</a>' +
                    '</div>'+
                    '<div class="operation-retry">' +
                    '    <a class="operation-discard">Discard</a>' +
                    '</div>'+
                    '    <a class="deletecomponent_link">Delete</a>' +
                    '</div>'
                ),
                model: this.mockModel
            });
            this.view.bindUIElements();
            this.view.onRender();

            this.viewSuccess = new JIRA.Projects.Components.ItemView({
                el: jQuery(
                    '<div>' +
                    '    <a class="aui-dropdown2-trigger" aria-owns="version-filter-status-dropdown">Status: Unreleased</a>' +
                    '    <input type="text" class="text" value="">' +
                    '</div>'
                ),
                model: this.mockModel
            });
            this.viewSuccess.bindUIElements();
        }
    });

    test('View should initially have a listener for model events', function () {
        this.view.listenTo = sinon.spy();
        this.view.delegateEvents();

        equal(this.view.listenTo.callCount, 2, "listenTo called for all model events");
        ok(this.view.listenTo.calledWith(this.mockModel, "change"), "listenTo model `change` event");
        ok(this.view.listenTo.calledWith(this.mockModel, "retry-delete"), "listenTo model `retry-delete` event");
    });

    test('View listen to outer elements (dropdown items) events after onRender call', function () {
        this.view._onElement = sinon.spy();
        this.view.onRender();

        equal(this.view._onElement.callCount, 2, "listenTo all events from elements outside of view");
        ok(this.view._onElement.calledWith(this.view.ui.deleteLink, "click"), "listenTo dropdown delete link `click` event");
    });

    test('Clicking retryAdd should trigger retry-add event on model', function () {
        this.view.ui.retryAddButton.trigger("click");

        ok(this.mockModel.trigger.calledOnce, "Trigger was called only once");
        ok(this.mockModel.trigger.calledWith("retry-add", this.mockModel));
    });

    test('Clicking retryDelete should trigger retry-delete event on model', function () {
        this.view.ui.retryDeleteButton.trigger("click");

        ok(this.mockModel.trigger.calledOnce, "Trigger was called only once");
        ok(this.mockModel.trigger.calledWith("retry-delete", this.mockModel));
    });

    test('Clicking discard should trigger model.discard()', function () {
        this.view.ui.discard.trigger("click");

        ok(this.mockModel.discard.calledOnce, "Trigger was called only once");
    });
});

==> jira-projects-plugin-6.0.5.jar: page/project/components/ItemView-test.js <==
AJS.test.require(["com.atlassian.jira.jira-projects-plugin:components-page-assets"], function(){
    "use strict";

    var jQuery = require("jquery");
    var Backbone = require("jira-projects-backbone");
    var ItemView = require("jira/projects/components/itemview");

    module('jira/projects/components/itemview', {
        setup: function () {
            this.mockModel = new Backbone.Model();
            sinon.stub(this.mockModel, "trigger");
            this.mockModel.discard = sinon.stub();
            sinon.stub(this.mockModel, "on");
            sinon.stub(this.mockModel, "off");

            this.view = new ItemView({
                el: jQuery(
                    '<div>'+
                    '<div class="operation-retry operation-add">' +
                    '    <a class="operation-retry retry-operation-add">Retry add</a>' +
                    '</div>'+
                    '<div class="operation-retry operation-delete">' +
                    '    <a class="operation-retry retry-operation-delete">Retry delete</a>' +
                    '</div>'+
                    '<div class="operation-retry">' +
                    '    <a class="operation-discard retry-operation-discard">Discard</a>' +
                    '</div>'+
                    '    <a class="deletecomponent_link">Delete</a>' +
                    '</div>'
                ),
                model: this.mockModel
            });
            this.view.bindUIElements();
            this.view.onRender();
        }
    });

    test('View should initially have a listener for model events', function () {
        this.view.listenTo = sinon.spy();
        this.view.delegateEvents();

        equal(this.view.listenTo.callCount, 3, "listenTo called for all model events");
        ok(this.view.listenTo.calledWith(this.mockModel, "change"), "listenTo model `change` event");
        ok(this.view.listenTo.calledWith(this.mockModel, "retry-update"), "listenTo model `retry-update` event");
        ok(this.view.listenTo.calledWith(this.mockModel, "retry-delete"), "listenTo model `retry-delete` event");
    });

    test('View listen to outer elements (dropdown items) events after onRender call', function () {
        this.view._onElement = sinon.spy();
        this.view.onRender();

        equal(this.view._onElement.callCount, 4, "listenTo all events from elements outside of view");
        ok(this.view._onElement.calledWith(this.view.ui.deleteLink, "click"), "listenTo dropdown delete link `click` event");
        ok(this.view._onElement.calledWith(this.view.ui.archiveButton, "click"), "listenTo dropdown archive link `click` event");
        ok(this.view._onElement.calledWith(this.view.ui.restoreButton, "click"), "listenTo dropdown restore link `click` event");
    });

    test('Clicking retryAdd should trigger retry-add event on model', function () {
        this.view.ui.retryAddButton.trigger("click");

        ok(this.mockModel.trigger.calledOnce, "Trigger was called only once");
        ok(this.mockModel.trigger.calledWith("retry-add", this.mockModel));
    });

    test('Clicking retryDelete should trigger retry-delete event on model', function () {
        this.view.ui.retryDeleteButton.trigger("click");

        ok(this.mockModel.trigger.calledOnce, "Trigger was called only once");
        ok(this.mockModel.trigger.calledWith("retry-delete", this.mockModel));
    });

    test('Clicking discard should trigger model.discard()', function () {
        this.view.ui.discard.trigger("click");

        ok(this.mockModel.discard.calledOnce, "Trigger was called only once");
    });
});
